==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Verzenden");
define("_URL","URL");
define("_PRINTER","Printervriendelijke pagina");
define("_FRIEND","Stuur dit verhaal naar een kennis");
define("_YOURNAME","Uw naam");
define("_OK","Ok!");
define("_RELATED","Gerelateerde links");
define("_MOREABOUT","Meer over");
define("_NEWSBY","Nieuws door");
define("_MOSTREAD","Meest gelezen verhaal om");
define("_READMORE","Meer lezen...");
define("_BYTESMORE","bytes meer");
define("_COMMENTSQ","Opmerkingen?");
define("_COMMENT","Opmerkingen");
define("_CONFIGURE","Aanpassen");
define("_LOGINCREATE","Login/Creer een account");
define("_THRESHOLD","Limiet");
define("_NOCOMMENTS","Geen opmerkingen");
define("_NESTED","Genest");
define("_FLAT","Plat");
define("_THREAD","Draad");
define("_OLDEST","Oudste eerst");
define("_NEWEST","Nieuwste eerst");
define("_HIGHEST","Meest gelezen eerst");
define("_COMMENTSWARNING","De schrijver is verantwoordelijk voor de inhoud van zijn berichten. 
define("_SCORE","Score:");
define("_USERINFO","Gebruikersinformatie");
define("_READREST","Lees de rest van deze opmerking...");
define("_REPLY","Reageer op dit bericht");
define("_REPLYMAIN","Opmerking plaatsen");
define("_NOSUBJECT","Geen onderwerp");
define("_NOANONCOMMENTS","Gasten mogen geen opmerkingen plaatsen, <a href=\"modules.php?name=Your_Account\">registreer</a> a.u.b.");
define("_PARENT","Parent");
define("_ROOT","Root");
define("_UCOMMENT","Opmerking");
define("_ALLOWEDHTML","Toegestane HTML:");
define("_POSTANON","Anoniem plaatsen");
define("_EXTRANS","Extrans (HTML-tags naar tekst)");
define("_HTMLFORMATED","HTML Geformatteerd");
define("_PLAINTEXT","Alleen tekst");
define("_ONN","op...");
define("_SUBJECT","Onderwerp");
define("_COMMENTREPLY","Opmerking plaatsen");
define("_COMREPLYPRE","Opmerking plaatsen voorbeeld");
define("_NOTRIGHT","Fout in een functievariabele.");
define("_SENDAMSG","Stuur een bericht");
define("_YOUSENDSTORY","U verzend het verhaal");
define("_TOAFRIEND","naar een specifieke kennis:");
define("_FYOURNAME","Uw naam:");
define("_FYOUREMAIL","Uw e-mail:");
define("_FFRIENDNAME","De naam van uw kennis:");
define("_FFRIENDEMAIL","Het e-mailadres van uw kennis:");
define("_INTERESTING","Interessant artikel op");
define("_HELLO","Hallo");
define("_YOURFRIEND","Uw kennis");
define("_CONSIDERED","vond het volgende artikel interessant en wilde het naar u sturen.");
define("_FDATE","Datum:");
define("_FTOPIC","Onderwerp:");
define("_YOUCANREAD","U kunt interessante artikelen lezen op");
define("_FSTORY","Verhaal");
define("_HASSENT","Is verzonden naar");
define("_THANKS","Bedankt!");
define("_RECOMMEND","Deze ste aanbevelen aan een kennis");
define("_PDATE","Datum:");
define("_PTOPIC","Onderwerp:");
define("_COMESFROM","Dit artikel komt van");
define("_THEURL","De URL voor dit verhaal is:");
define("_PREVIEW","Preview");
define("_NEWUSER","Nieuwe gebruiker");
define("_OPTIONS","Opties");
define("_REFRESH","Vernieuw");
define("_ADD","Toevoegen");
define("_NOCOMMENTSACT","Voor dit verhaal is helaas geen commentaar beschikbaar.");
define("_ARTICLEPOLL","Peiling van artikel");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Verzenden");
define("_URL","URL");
define("_PRINTER","Printervriendelijke pagina");
define("_FRIEND","Stuur dit verhaal naar een kennis");
define("_YOURNAME","Uw naam");
define("_OK","Ok!");
define("_RELATED","Gerelateerde links");
define("_MOREABOUT","Meer over");
define("_NEWSBY","Nieuws door");
define("_MOSTREAD","Meest gelezen verhaal om");
define("_READMORE","Meer lezen...");
define("_BYTESMORE","bytes meer");
define("_COMMENTSQ","Opmerkingen?");
define("_COMMENT","Opmerkingen");
define("_CONFIGURE","Aanpassen");
define("_LOGINCREATE","Login/Creer een account");
define("_THRESHOLD","Limiet");
define("_NOCOMMENTS","Geen opmerkingen");
define("_NESTED","Genest");
define("_FLAT","Plat");
define("_THREAD","Draad");
define("_OLDEST","Oudste eerst");
define("_NEWEST","Nieuwste eerst");
define("_HIGHEST","Meest gelezen eerst");
define("_COMMENTSWARNING","De schrijver is verantwoordelijk voor de inhoud van zijn berichten.";
define("_SCORE","Score:");
define("_USERINFO","Gebruikersinformatie");
define("_READREST","Lees de rest van deze opmerking...");
define("_REPLY","Reageer op dit bericht");
define("_REPLYMAIN","Opmerking plaatsen");
define("_NOSUBJECT","Geen onderwerp");
define("_NOANONCOMMENTS","Gasten mogen geen opmerkingen plaatsen, <a href=\"modules.php?name=Your_Account\">registreer</a> a.u.b.");
define("_PARENT","Parent");
define("_ROOT","Root");
define("_UCOMMENT","Opmerking");
define("_ALLOWEDHTML","Toegestane HTML:");
define("_POSTANON","Anoniem plaatsen");
define("_EXTRANS","Extrans (HTML-tags naar tekst)");
define("_HTMLFORMATED","HTML Geformatteerd");
define("_PLAINTEXT","Alleen tekst");
define("_ONN","op...");
define("_SUBJECT","Onderwerp");
define("_COMMENTREPLY","Opmerking plaatsen");
define("_COMREPLYPRE","Opmerking plaatsen voorbeeld");
define("_NOTRIGHT","Fout in een functievariabele.");
define("_SENDAMSG","Stuur een bericht");
define("_YOUSENDSTORY","U verzend het verhaal");
define("_TOAFRIEND","naar een specifieke kennis:");
define("_FYOURNAME","Uw naam:");
define("_FYOUREMAIL","Uw e-mail:");
define("_FFRIENDNAME","De naam van uw kennis:");
define("_FFRIENDEMAIL","Het e-mailadres van uw kennis:");
define("_INTERESTING","Interessant artikel op");
define("_HELLO","Hallo");
define("_YOURFRIEND","Uw kennis");
define("_CONSIDERED","vond het volgende artikel interessant en wilde het naar u sturen.");
define("_FDATE","Datum:");
define("_FTOPIC","Onderwerp:");
define("_YOUCANREAD","U kunt interessante artikelen lezen op");
define("_FSTORY","Verhaal");
define("_HASSENT","Is verzonden naar");
define("_THANKS","Bedankt!");
define("_RECOMMEND","Deze ste aanbevelen aan een kennis");
define("_PDATE","Datum:");
define("_PTOPIC","Onderwerp:");
define("_COMESFROM","Dit artikel komt van");
define("_THEURL","De URL voor dit verhaal is:");
define("_PREVIEW","Preview");
define("_NEWUSER","Nieuwe gebruiker");
define("_OPTIONS","Opties");
define("_REFRESH","Vernieuw");
define("_ADD","Toevoegen");
define("_NOCOMMENTSACT","Voor dit verhaal is helaas geen commentaar beschikbaar.");
define("_ARTICLEPOLL","Peiling van artikel");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
